genshi.template.base.TemplateSyntaxError

Package genshi :: Package template :: Module base :: Class TemplateSyntaxError |

# Class TemplateSyntaxError

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                       TemplateError --+
                                       |
                                      TemplateSyntaxError

Known Subclasses:
  - BadDirectiveError

Exception raised when an expression in a template causes a Python syntax error, or the template is not well-formed.

Instance Methods
__init__(self, message, filename=None, lineno=-1, offset=-1) Create the exception |
Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Instance Variables
Inherited from `TemplateError`: `filename`, `lineno`, `msg`, `offset`

Properties
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details

### __init__(self, message, filename=None, lineno=-1, offset=-1) (Constructor) |
Create the exception Parameters: `message` - the error message `filename` - the filename of the template `lineno` - the number of line in the template at which the error occurred `offset` - the column number at which the error occurred Overrides: object.__init__